Metadata management
*******************

Balder uses a lot of inner hidden class properties that manages the workflow of balder. This section describes them.

.. warning::
    Please note: This section is currently under development and will be released shortly!

..
    .. todo